@@ -1,4 +1,4 @@
-# $Id: TLPSRC.pm 48145 2018-07-05 21:20:15Z karl $
+# $Id: TLPSRC.pm 48916 2018-10-16 03:29:12Z preining $
 # TeXLive::TLPSRC.pm - module for handling tlpsrc files
 # Copyright 2007-2018 Norbert Preining
 # This file is licensed under the GNU General Public License version 2
@@ -12,7 +12,7 @@ use TeXLive::TLUtils;
 use TeXLive::TLPOBJ;
 use TeXLive::TLTREE;
 
-my $svnrev = '$Revision: 48145 $';
+my $svnrev = '$Revision: 48916 $';
 my $_modulerevision = ($svnrev =~ m/: ([0-9]+) /) ? $1 : "unknown";
 sub module_revision { return $_modulerevision; }
 
@@ -145,7 +145,7 @@ sub from_file {
 
     } elsif ($line =~ /^shortdesc\s*(.*)$/) {
       # although we would like to do this, hyphen-latin.tlpsrc contains
-      # multiple short/longdesc entries. Not worth following up.
+      # multiple short/longdesc, entries. Not worth following up.
       # $shortdesc
       #   && die "$srcfile:$lineno: second shortdesc not allowed: $line"
       #          . "(have $shortdesc)\n";
@@ -297,6 +297,12 @@ sub make_tlpobj {
         }
       }
     }
+    # we might have added the package name itself to its dependencies due
+    # to the parse_AddFormat_line. Remove it
+    @deps = (defined($tlp->depends) ? $tlp->depends : ());
+    my $tlpname = $tlp->name;
+    my @newdeps = grep { $_ ne $tlpname } @deps;
+    $tlp->depends(@newdeps);
   }
 
   my $filemax;
@@ -795,7 +801,7 @@ Catalogue.
 =item C<shortdesc>
 
 gives a one line description of the package. Subsequent entries will
-overwrite the former ones. In TeX Live only used for collections and
+overwrite the former ones. In TeX Live primarily used for collections and
 schemes.
 
 =item C<longdesc>
